@@ -23,6 +23,7 @@
 
 #include <string.h>
 #include "window.h"
+#include "class-group.h"
 #include "xutils.h"
 #include "private.h"
 #include "wnck-enum-types.h"
@@ -52,6 +53,7 @@ struct _WnckWindowPrivate
   Window xwindow;
   WnckScreen *screen;
   WnckApplication *app;
+  WnckClassGroup *class_group;
   Window group_leader;
   Window transient_for;
   char *name;
@@ -479,6 +481,14 @@ wnck_window_get_xid (WnckWindow *window)
   return window->priv->xwindow;
 }
 
+WnckClassGroup *
+wnck_window_get_class_group (WnckWindow *window)
+{
+  g_return_val_if_fail (WNCK_IS_WINDOW (window), NULL);
+
+  return window->priv->class_group;
+}
+
 /**
  * wnck_window_get_session_id:
  * @window: a #WnckWindow
@@ -1034,7 +1044,8 @@ find_last_transient_for (GList *windows,
     {
       WnckWindow *w = tmp->data;
 
-      if (w->priv->transient_for == xwindow)
+      if (w->priv->transient_for == xwindow &&
+	  w->priv->wintype != WNCK_WINDOW_UTILITY)
         retval = w;
       
       tmp = tmp->next;
@@ -1361,6 +1372,20 @@ _wnck_window_set_application (WnckWindow      *window,
   window->priv->app = app;
 }
 
+void
+_wnck_window_set_class_group (WnckWindow     *window,
+			      WnckClassGroup *class_group)
+{
+  g_return_if_fail (WNCK_IS_WINDOW (window));
+  g_return_if_fail (class_group == NULL || WNCK_IS_CLASS_GROUP (class_group));
+
+  if (class_group)
+    g_object_ref (G_OBJECT (class_group));
+  if (window->priv->class_group)
+    g_object_unref (G_OBJECT (window->priv->class_group));
+  window->priv->class_group = class_group;
+}
+
 void
 _wnck_window_process_property_notify (WnckWindow *window,
                                       XEvent     *xevent)
@@ -1906,6 +1931,7 @@ force_update_now (WnckWindow *window)
   WnckWindowActions old_actions;
   char *old_name;
   char *old_icon_name;
+  gboolean do_emit_name_changed = FALSE;
   
   unqueue_update (window);
 
@@ -1925,7 +1951,7 @@ force_update_now (WnckWindow *window)
   else
     {
       if (strcmp (window->priv->name, old_name) != 0)
-        emit_name_changed (window);
+        do_emit_name_changed = TRUE;
       g_free (old_name);
     }
 
@@ -1940,10 +1966,13 @@ force_update_now (WnckWindow *window)
     {
       if (old_icon_name == NULL ||
           strcmp (window->priv->icon_name, old_icon_name) != 0)
-        emit_name_changed (window);
+        do_emit_name_changed = TRUE;
       g_free (old_icon_name);
     }
 
+  if (do_emit_name_changed)
+    emit_name_changed (window);
+
   old_state = COMPRESS_STATE (window);
   old_actions = window->priv->actions;
 
